@@ -10,18 +10,8 @@ fi
 #fi
 
 if [ ! -d /sys/firmware/efi/efivars ]; then
-    sudo sed -i -e 's|"xfs","ext4","zfs"|"ext4"|' /usr/share/calamares/modules/partition.conf
+    sudo sed -i -e 's|"xfs","ext4","btrfs","zfs"|"ext4"|' /usr/share/calamares/modules/partition.conf
     sudo sed -i -e 's|defaultFileSystemType:  "xfs"|defaultFileSystemType:  "ext4"|' /usr/share/calamares/modules/partition.conf
 fi
 
-pkexec --disable-internal-agent env \
-    DBUS_SESSION_BUS_ADDRESS="$DBUS_SESSION_BUS_ADDRESS" \
-    WAYLAND_DISPLAY="$WAYLAND_DISPLAY" \
-    XDG_RUNTIME_DIR="$XDG_RUNTIME_DIR" \
-    HOME="$HOME" \
-    QT_STYLE_OVERRIDE="$QT_STYLE_OVERRIDE" \
-    QT_QPA_PLATFORMTHEME="$QT_QPA_PLATFORMTHEME" \
-    QT_QPA_PLATFORM="wayland" \
-    XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" \
-    XDG_SESSION_TYPE="wayland" \
-    "/usr/bin/calamares" "-d" "$@" > installation.log
+sudo /usr/bin/calamares -d > installation.log
