@@ -40,6 +40,7 @@ def run():
         '.config/autostart',
         '.config/niri',
         '.config/noctalia',
+        '.config/qt6ct/colors',
         '.config/plasma-workspace/env',
         '.config/Kvantum'
     ]
@@ -71,6 +72,8 @@ def run():
         ('startupconfigkeys', '.config/'),
         ('config.kdl', '.config/niri/'),
         ('noctalia.kdl', '.config/niri/'),
+        ('qt6ct.conf', '.config/qt6ct/'),
+        ('noctalia.conf', '.config/qt6ct/colors/'),
         ('colors.json', '.config/noctalia/'),
         ('settings.json', '.config/noctalia/')
     ]
